summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLiliana Marie Prikler <liliana.prikler@gmail.com>2025-04-19 07:20:24 +0200
committerAndreas Enge <andreas@enge.fr>2026-03-06 14:52:04 +0100
commit1bca474d01eb744cb75f99e187336f94e2e7f1c8 (patch)
tree77d613f225840ff83b1331032ab71cc1929a347c
parent69ed70167ec9d337e08199d4a130ba4797662de8 (diff)
gnu: pango: Update to 1.56.4.
* gnu/packages/patches/pango-skip-libthai-test.patch: Delete file. * gnu/local.mk (dist_patch_DATA): Unregister it. * gnu/packages/gtk.scm (pango): Update to 1.56.4. [source]: Change to git-fetch. [arguments]: Convert to list of G-Expressions. <#:configure-flags>: Add “-Dintrospection=enabled”. <#:phases> {disable-cantarell-tests}: Skip test-font-data. Change-Id: I044f465555a7a64bb938f41a738bfa720d8ea51e
-rw-r--r--gnu/local.mk1
-rw-r--r--gnu/packages/gtk.scm40
-rw-r--r--gnu/packages/patches/pango-skip-libthai-test.patch23
3 files changed, 22 insertions, 42 deletions
diff --git a/gnu/local.mk b/gnu/local.mk
index cb8d18867cc..f4fd1ebe72b 100644
--- a/gnu/local.mk
+++ b/gnu/local.mk
@@ -2060,7 +2060,6 @@ dist_patch_DATA = \
%D%/packages/patches/pnet-newer-libgc-fix.patch \
%D%/packages/patches/pnet-newer-texinfo-fix.patch \
%D%/packages/patches/pam-krb5-CVE-2020-10595.patch \
- %D%/packages/patches/pango-skip-libthai-test.patch \
%D%/packages/patches/password-store-tree-compat.patch \
%D%/packages/patches/pciutils-hurd64.patch \
%D%/packages/patches/pcsxr-find-harfbuzz.patch \
diff --git a/gnu/packages/patches/pango-skip-libthai-test.patch b/gnu/packages/patches/pango-skip-libthai-test.patch
deleted file mode 100644
index 98732b53913..00000000000
--- a/gnu/packages/patches/pango-skip-libthai-test.patch
+++ /dev/null
@@ -1,23 +0,0 @@
-Skip Thai character test when libthai is unavailable.
-
-Taken from upstream bug tracker:
-https://gitlab.gnome.org/GNOME/pango/merge_requests/161
-https://gitlab.gnome.org/GNOME/pango/commit/b73284747ac937e31dc9191f84ed6e24284c88ee
-
-diff --git a/tests/test-break.c b/tests/test-break.c
-index 8549b678bba69360d07dce3af21d915412f20d51..47fa3009165e19a331aa04a0df4351ae2323933b 100644
---- a/tests/test-break.c
-+++ b/tests/test-break.c
-@@ -305,6 +305,12 @@ main (int argc, char *argv[])
- if (!strstr (name, "break"))
- continue;
-
-+#ifndef HAVE_LIBTHAI
-+ /* four.break involves Thai, so only test it when we have libthai */
-+ if (strstr (name, "four.break"))
-+ continue;
-+#endif
-+
- path = g_strdup_printf ("/break/%s", name);
- g_test_add_data_func_full (path, g_test_build_filename (G_TEST_DIST, "breaks", name, NULL),
- test_break, g_free);
diff --git a/gnu/packages/gtk.scm b/gnu/packages/gtk.scm
index 816990f9ee1..ce3bd5d48c9 100644
--- a/gnu/packages/gtk.scm
+++ b/gnu/packages/gtk.scm
@@ -387,29 +387,33 @@ applications.")
(define-public pango
(package
(name "pango")
- (version "1.54.0")
+ (version "1.56.4")
(source (origin
- (method url-fetch)
- (uri (string-append "mirror://gnome/sources/pango/"
- (version-major+minor version) "/"
- name "-" version ".tar.xz"))
- (patches (search-patches "pango-skip-libthai-test.patch"))
+ (method git-fetch)
+ (uri (git-reference
+ (url "https://gitlab.gnome.org/GNOME/pango")
+ (commit version)))
+ (file-name (git-file-name name version))
(sha256
(base32
- "1n0y5l5wfq2a86dimraazvz1v9dvqdjkmpqgzkbk9rqy09syv7la"))))
+ "0jnmydds9dmdah4fjj5rr5gmf1imxlxjc0w98if642n98vmsdf67"))))
(build-system meson-build-system)
(arguments
- '(#:glib-or-gtk? #t ; To wrap binaries and/or compile schemas
- #:phases (modify-phases %standard-phases
- (add-after 'unpack 'disable-cantarell-tests
- (lambda _
- (substitute* "tests/meson.build"
- ;; XXX FIXME: These tests require "font-abattis-cantarell", but
- ;; adding it here would introduce a circular dependency.
- (("\\[ 'test-layout'.*") "")
- (("\\[ 'test-itemize'.*") "")
- (("\\[ 'test-font'.*") "")
- (("\\[ 'test-harfbuzz'.*") "")))))))
+ (list
+ #:glib-or-gtk? #t ; To wrap binaries and/or compile schemas
+ #:configure-flags (if (target-hurd?)
+ #~(list)
+ #~(list "-Dintrospection=enabled"))
+ #:phases #~(modify-phases %standard-phases
+ (add-after 'unpack 'disable-cantarell-tests
+ (lambda _
+ (substitute* "tests/meson.build"
+ ;; XXX FIXME: These tests require "font-abattis-cantarell", but
+ ;; adding it here would introduce a circular dependency.
+ (("\\[ 'test-layout'.*") "")
+ (("\\[ 'test-itemize'.*") "")
+ (("\\[ 'test-font(-data)?'.*") "")
+ (("\\[ 'test-harfbuzz'.*") "")))))))
(propagated-inputs
;; These are all in Requires or Requires.private of the '.pc' files.
(list cairo